summaryrefslogtreecommitdiff
path: root/lib/mkostemps.c
diff options
context:
space:
mode:
authorEric Blake <ebb9@byu.net>2009-11-17 11:53:14 -0700
committerEric Blake <ebb9@byu.net>2009-11-17 22:15:29 -0700
commit83e045030538b7838367305c0b92c7c756c90651 (patch)
tree97f5346f55106b512dfee252360021cf4b7065d3 /lib/mkostemps.c
parent89fe4c9d24e052d1947575379792613eb82f37cb (diff)
downloadgnulib-83e045030538b7838367305c0b92c7c756c90651.tar.gz
mkstemp: avoid conflict with C++ keyword template
Just because glibc uses K&R, and uses template as an identifier, doesn't mean we have to. * lib/mkdtemp.c (mkdtemp): Change spelling of template. * lib/mkostemp.c (mkostemp): Likewise. * lib/mkostemps.c (mkostemps): Likewise. * lib/mkstemp.c (mkstemp): Likewise. * lib/mkstemps.c (mkstemps): Likewise. Signed-off-by: Eric Blake <ebb9@byu.net>
Diffstat (limited to 'lib/mkostemps.c')
-rw-r--r--lib/mkostemps.c11
1 files changed, 4 insertions, 7 deletions
diff --git a/lib/mkostemps.c b/lib/mkostemps.c
index 8de90fe2b2..98475ff5e9 100644
--- a/lib/mkostemps.c
+++ b/lib/mkostemps.c
@@ -37,15 +37,12 @@
# define __GT_FILE 0
#endif
-/* Generate a unique temporary file name from TEMPLATE. The last six
- characters before a suffix of length SUFFIXLEN of TEMPLATE must be
+/* Generate a unique temporary file name from XTEMPLATE. The last six
+ characters before a suffix of length SUFFIXLEN of XTEMPLATE must be
"XXXXXX"; they are replaced with a string that makes the filename
unique. Then open the file and return a fd. */
int
-mkostemps (template, suffixlen, flags)
- char *template;
- int suffixlen;
- int flags;
+mkostemps (char *xtemplate, int suffixlen, int flags)
{
if (suffixlen < 0)
{
@@ -53,5 +50,5 @@ mkostemps (template, suffixlen, flags)
return -1;
}
- return __gen_tempname (template, suffixlen, flags, __GT_FILE);
+ return __gen_tempname (xtemplate, suffixlen, flags, __GT_FILE);
}